diff --git a/contrib/devtools/README.md b/contrib/devtools/README.md
index 31256fe4eea44..e99603f3d57f8 100644
--- a/contrib/devtools/README.md
+++ b/contrib/devtools/README.md
@@ -100,7 +100,7 @@ options, as all its configuration is set at the top of the file. It runs many ti
pypy3 contrib/devtools/headerssync-params.py
```
-gen-bitcoin-conf.sh
+gen-navcoin-conf.sh
===================
Generates a navcoin.conf file in `share/examples/` by parsing the output from `navcoind --help`. This script is run during the
@@ -112,7 +112,7 @@ repository. To use this tool with out-of-tree builds set `BUILDDIR`. For
example:
```bash
-BUILDDIR=$PWD/build contrib/devtools/gen-bitcoin-conf.sh
+BUILDDIR=$PWD/build contrib/devtools/gen-navcoin-conf.sh
```
security-check.py and test-security-check.py
diff --git a/contrib/init/navcoind.conf b/contrib/init/navcoind.conf
index 4bb7e9bb3c3a2..1a7fd04f2d869 100644
--- a/contrib/init/navcoind.conf
+++ b/contrib/init/navcoind.conf
@@ -9,7 +9,7 @@ env BITCOIND_GROUP="bitcoin"
env BITCOIND_PIDDIR="/var/run/navcoind"
# upstart can't handle variables constructed with other variables
env BITCOIND_PIDFILE="/var/run/navcoind/navcoind.pid"
-env BITCOIND_CONFIGFILE="/etc/bitcoin/bitcoin.conf"
+env BITCOIND_CONFIGFILE="/etc/navcoin/navcoin.conf"
env BITCOIND_DATADIR="/var/lib/navcoind"
expect fork
diff --git a/contrib/init/navcoind.openrc b/contrib/init/navcoind.openrc
index 69b1234512388..78bd2b63f3b21 100644
--- a/contrib/init/navcoind.openrc
+++ b/contrib/init/navcoind.openrc
@@ -8,7 +8,7 @@ else
BITCOIND_DEFAULT_DATADIR="/var/lib/navcoind"
fi
-BITCOIND_CONFIGFILE=${BITCOIND_CONFIGFILE:-/etc/bitcoin/bitcoin.conf}
+BITCOIND_CONFIGFILE=${BITCOIND_CONFIGFILE:-/etc/navcoin/navcoin.conf}
BITCOIND_PIDDIR=${BITCOIND_PIDDIR:-/var/run/navcoind}
BITCOIND_PIDFILE=${BITCOIND_PIDFILE:-${BITCOIND_PIDDIR}/navcoind.pid}
BITCOIND_DATADIR=${BITCOIND_DATADIR:-${BITCOIND_DEFAULT_DATADIR}}
diff --git a/contrib/init/navcoind.openrcconf b/contrib/init/navcoind.openrcconf
index e7ea5f0d24d1a..a23a8f734e23b 100644
--- a/contrib/init/navcoind.openrcconf
+++ b/contrib/init/navcoind.openrcconf
@@ -1,7 +1,7 @@
# /etc/conf.d/navcoind: config file for /etc/init.d/navcoind
# Config file location
-#BITCOIND_CONFIGFILE="/etc/bitcoin/bitcoin.conf"
+#BITCOIND_CONFIGFILE="/etc/navcoin/navcoin.conf"
# What directory to write pidfile to? (created and owned by $BITCOIND_USER)
#BITCOIND_PIDDIR="/var/run/navcoind"
diff --git a/contrib/init/navcoind.service b/contrib/init/navcoind.service
index e56c33f4a3120..61d0507cc2e69 100644
--- a/contrib/init/navcoind.service
+++ b/contrib/init/navcoind.service
@@ -5,7 +5,7 @@
# See "man systemd.service" for details.
# Note that almost all daemon options could be specified in
-# /etc/bitcoin/bitcoin.conf, but keep in mind those explicitly
+# /etc/navcoin/navcoin.conf, but keep in mind those explicitly
# specified as arguments in ExecStart= will override those in the
# config file.
@@ -19,7 +19,7 @@ Wants=network-online.target
[Service]
ExecStart=/usr/bin/navcoind -pid=/run/navcoind/navcoind.pid \
- -conf=/etc/bitcoin/bitcoin.conf \
+ -conf=/etc/navcoin/navcoin.conf \
-datadir=/var/lib/navcoind \
-startupnotify='systemd-notify --ready' \
-shutdownnotify='systemd-notify --stopping'
diff --git a/doc/README.md b/doc/README.md
index a03e8ed14b4cb..910702a3d714c 100644
--- a/doc/README.md
+++ b/doc/README.md
@@ -71,7 +71,7 @@ The Bitcoin repo's [root README](/README.md) contains relevant information on th
### Miscellaneous
- [Assets Attribution](assets-attribution.md)
-- [bitcoin.conf Configuration File](bitcoin-conf.md)
+- [navcoin.conf Configuration File](bitcoin-conf.md)
- [CJDNS Support](cjdns.md)
- [Files](files.md)
- [Fuzz-testing](fuzzing.md)
diff --git a/doc/build-osx.md b/doc/build-osx.md
index ef91758691771..87f850cd720a6 100644
--- a/doc/build-osx.md
+++ b/doc/build-osx.md
@@ -248,9 +248,9 @@ Before running, you may create an empty configuration file:
```shell
mkdir -p "/Users/${USER}/Library/Application Support/Bitcoin"
-touch "/Users/${USER}/Library/Application Support/Bitcoin/bitcoin.conf"
+touch "/Users/${USER}/Library/Application Support/Bitcoin/navcoin.conf"
-chmod 600 "/Users/${USER}/Library/Application Support/Bitcoin/bitcoin.conf"
+chmod 600 "/Users/${USER}/Library/Application Support/Bitcoin/navcoin.conf"
```
You can monitor the download process by looking at the debug.log file:
diff --git a/doc/files.md b/doc/files.md
index aa15eacd2929c..5c8b6ca74c9d2 100644
--- a/doc/files.md
+++ b/doc/files.md
@@ -32,7 +32,7 @@ Windows | `%APPDATA%\Bitcoin\` [\[1\]](#note1)
2. A custom data directory path can be specified with the `-datadir` option.
-3. All content of the data directory, except for `bitcoin.conf` file, is chain-specific. This means the actual data directory paths for non-mainnet cases differ:
+3. All content of the data directory, except for `navcoin.conf` file, is chain-specific. This means the actual data directory paths for non-mainnet cases differ:
Chain option | Data directory path
-------------------------------|------------------------------
@@ -57,7 +57,7 @@ Subdirectory | File(s) | Description
`wallets/` | | [Contains wallets](#multi-wallet-environment); can be specified by `-walletdir` option; if `wallets/` subdirectory does not exist, wallets reside in the [data directory](#data-directory-location)
`./` | `anchors.dat` | Anchor IP address database, created on shutdown and deleted at startup. Anchors are last known outgoing block-relay-only peers that are tried to re-connect to on startup
`./` | `banlist.json` | Stores the addresses/subnets of banned nodes.
-`./` | `bitcoin.conf` | User-defined [configuration settings](bitcoin-conf.md) for `navcoind` or `navcoin-qt`. File is not written to by the software and must be created manually. Path can be specified by `-conf` option
+`./` | `navcoin.conf` | User-defined [configuration settings](bitcoin-conf.md) for `navcoind` or `navcoin-qt`. File is not written to by the software and must be created manually. Path can be specified by `-conf` option
`./` | `navcoind.pid` | Stores the process ID (PID) of `navcoind` or `navcoin-qt` while running; created at start and deleted on shutdown; can be specified by `-pid` option
`./` | `debug.log` | Contains debug information and general logging generated by `navcoind` or `navcoin-qt`; can be specified by `-debuglogfile` option
`./` | `fee_estimates.dat` | Stores statistics used to estimate minimum transaction fees required for confirmation
@@ -67,7 +67,7 @@ Subdirectory | File(s) | Description
`./` | `onion_v3_private_key` | Cached Tor onion service private key for `-listenonion` option
`./` | `i2p_private_key` | Private key that corresponds to our I2P address. When `-i2psam=` is specified the contents of this file is used to identify ourselves for making outgoing connections to I2P peers and possibly accepting incoming ones. Automatically generated if it does not exist.
`./` | `peers.dat` | Peer IP address database (custom format)
-`./` | `settings.json` | Read-write settings set through GUI or RPC interfaces, augmenting manual settings from [bitcoin.conf](bitcoin-conf.md). File is created automatically if read-write settings storage is not disabled with `-nosettings` option. Path can be specified with `-settings` option
+`./` | `settings.json` | Read-write settings set through GUI or RPC interfaces, augmenting manual settings from [navcoin.conf](bitcoin-conf.md). File is created automatically if read-write settings storage is not disabled with `-nosettings` option. Path can be specified with `-settings` option
`./` | `.cookie` | Session RPC authentication cookie; if used, created at start and deleted on shutdown; can be specified by `-rpccookiefile` option
`./` | `.lock` | Data directory lock file
diff --git a/doc/init.md b/doc/init.md
index fbe2ba830ab65..0a83bf4bf744a 100644
--- a/doc/init.md
+++ b/doc/init.md
@@ -21,7 +21,7 @@ Configuration
---------------------------------
Running navcoind as a daemon does not require any manual configuration. You may
-set the `rpcauth` setting in the `bitcoin.conf` configuration file to override
+set the `rpcauth` setting in the `navcoin.conf` configuration file to override
the default behaviour of using a special cookie for authentication.
This password does not have to be remembered or typed as it is mostly used
@@ -44,7 +44,7 @@ This allows for running navcoind without having to do any manual configuration.
relative to the data directory. `wallet` *only* supports relative paths.
For an example configuration file that describes the configuration settings,
-see `share/examples/bitcoin.conf`.
+see `share/examples/navcoin.conf`.
Paths
---------------------------------
@@ -54,7 +54,7 @@ Paths
All three configurations assume several paths that might need to be adjusted.
Binary: /usr/bin/navcoind
- Configuration file: /etc/bitcoin/bitcoin.conf
+ Configuration file: /etc/navcoin/navcoin.conf
Data directory: /var/lib/navcoind
PID file: /var/run/navcoind/navcoind.pid (OpenRC and Upstart) or
/run/navcoind/navcoind.pid (systemd)
@@ -74,10 +74,10 @@ bitcoin group to do so. This does not allow
for the listing of files under the directory.
NOTE: It is not currently possible to override `datadir` in
-`/etc/bitcoin/bitcoin.conf` with the current systemd, OpenRC, and Upstart init
+`/etc/navcoin/navcoin.conf` with the current systemd, OpenRC, and Upstart init
files out-of-the-box. This is because the command line options specified in the
init files take precedence over the configurations in
-`/etc/bitcoin/bitcoin.conf`. However, some init systems have their own
+`/etc/navcoin/navcoin.conf`. However, some init systems have their own
configuration mechanisms that would allow for overriding the command line
options specified in the init files (e.g. setting `BITCOIND_DATADIR` for
OpenRC).
@@ -85,7 +85,7 @@ OpenRC).
### macOS
Binary: /usr/local/bin/navcoind
- Configuration file: ~/Library/Application Support/Bitcoin/bitcoin.conf
+ Configuration file: ~/Library/Application Support/Bitcoin/navcoin.conf
Data directory: ~/Library/Application Support/Bitcoin
Lock file: ~/Library/Application Support/Bitcoin/.lock
diff --git a/doc/bitcoin-conf.md b/doc/navcoin-conf.md
similarity index 86%
rename from doc/bitcoin-conf.md
rename to doc/navcoin-conf.md
index e08528f478c31..ef32c0c008f6d 100644
--- a/doc/bitcoin-conf.md
+++ b/doc/navcoin-conf.md
@@ -1,4 +1,4 @@
-# `bitcoin.conf` Configuration File
+# `navcoin.conf` Configuration File
The configuration file is used by `navcoind`, `navcoin-qt` and `navcoin-cli`.
@@ -51,24 +51,24 @@ rpcport=4000
## Configuration File Path
-The configuration file is not automatically created; you can create it using your favorite text editor. By default, the configuration file name is `bitcoin.conf` and it is located in the Bitcoin data directory, but both the Bitcoin data directory and the configuration file path may be changed using the `-datadir` and `-conf` command-line options.
+The configuration file is not automatically created; you can create it using your favorite text editor. By default, the configuration file name is `navcoin.conf` and it is located in the Bitcoin data directory, but both the Bitcoin data directory and the configuration file path may be changed using the `-datadir` and `-conf` command-line options.
-The `includeconf=` option in the `bitcoin.conf` file can be used to include additional configuration files.
+The `includeconf=` option in the `navcoin.conf` file can be used to include additional configuration files.
### Default configuration file locations
Operating System | Data Directory | Example Path
-- | -- | --
-Windows | `%APPDATA%\Bitcoin\` | `C:\Users\username\AppData\Roaming\Bitcoin\bitcoin.conf`
-Linux | `$HOME/.bitcoin/` | `/home/username/.bitcoin/bitcoin.conf`
-macOS | `$HOME/Library/Application Support/Bitcoin/` | `/Users/username/Library/Application Support/Bitcoin/bitcoin.conf`
+Windows | `%APPDATA%\Bitcoin\` | `C:\Users\username\AppData\Roaming\Bitcoin\navcoin.conf`
+Linux | `$HOME/.bitcoin/` | `/home/username/.navcoin/navcoin.conf`
+macOS | `$HOME/Library/Application Support/Bitcoin/` | `/Users/username/Library/Application Support/Bitcoin/navcoin.conf`
-An example configuration file can be generated by [contrib/devtools/gen-bitcoin-conf.sh](../contrib/devtools/gen-bitcoin-conf.sh).
+An example configuration file can be generated by [contrib/devtools/gen-navcoin-conf.sh](../contrib/devtools/gen-navcoin-conf.sh).
Run this script after compiling to generate an up-to-date configuration file.
-The output is placed under `share/examples/bitcoin.conf`.
+The output is placed under `share/examples/navcoin.conf`.
To use the generated configuration file, copy the example file into your data directory and edit it there, like so:
```
# example copy command for linux user
-cp share/examples/bitcoin.conf ~/.bitcoin
+cp share/examples/navcoin.conf ~/.bitcoin
```
diff --git a/doc/release-process.md b/doc/release-process.md
index 8279d9aac92b9..a4df57cf14cf5 100644
--- a/doc/release-process.md
+++ b/doc/release-process.md
@@ -8,7 +8,7 @@ Release Process
* Update translations see [translation_process.md](https://github.com/bitcoin/bitcoin/blob/master/doc/translation_process.md#synchronising-translations).
* Update release candidate version in `configure.ac` (`CLIENT_VERSION_RC`).
* Update manpages (after rebuilding the binaries), see [gen-manpages.py](https://github.com/bitcoin/bitcoin/blob/master/contrib/devtools/README.md#gen-manpagespy).
-* Update bitcoin.conf and commit, see [gen-bitcoin-conf.sh](https://github.com/bitcoin/bitcoin/blob/master/contrib/devtools/README.md#gen-bitcoin-confsh).
+* Update navcoin.conf and commit, see [gen-navcoin-conf.sh](https://github.com/bitcoin/bitcoin/blob/master/contrib/devtools/README.md#gen-navcoin-confsh).
### Before every major and minor release
diff --git a/doc/zmq.md b/doc/zmq.md
index 72afb58d759e2..df1546c854c4c 100644
--- a/doc/zmq.md
+++ b/doc/zmq.md
@@ -91,7 +91,7 @@ For instance:
Each PUB notification has a topic and body, where the header
corresponds to the notification type. For instance, for the
notification `-zmqpubhashtx` the topic is `hashtx` (no null
-terminator). These options can also be provided in bitcoin.conf.
+terminator). These options can also be provided in navcoin.conf.
The topics are:
diff --git a/share/examples/bitcoin.conf b/share/examples/navcoin.conf
similarity index 50%
rename from share/examples/bitcoin.conf
rename to share/examples/navcoin.conf
index 5bee4bf92e73c..70c2e093f239c 100644
--- a/share/examples/bitcoin.conf
+++ b/share/examples/navcoin.conf
@@ -1 +1 @@
-# This is a placeholder file. Please follow the instructions in `contrib/devtools/README.md` to generate a bitcoin.conf file.
+# This is a placeholder file. Please follow the instructions in `contrib/devtools/README.md` to generate a navcoin.conf file.
diff --git a/src/common/init.cpp b/src/common/init.cpp
index 412d73aec7016..45ec9cd92e4dc 100644
--- a/src/common/init.cpp
+++ b/src/common/init.cpp
@@ -30,7 +30,7 @@ std::optional InitConfig(ArgsManager& args, SettingsAbortFn setting
// possible for the config file to cause another configuration to be
// used, though. Specifying a conf= option in the config file causes a
// parse error, and specifying a datadir= location containing another
- // bitcoin.conf file just ignores the other file.)
+ // navcoin.conf file just ignores the other file.)
const fs::path orig_datadir_path{args.GetDataDirBase()};
const fs::path orig_config_path{AbsPathForConfigVal(args, args.GetPathArg("-conf", BITCOIN_CONF_FILENAME), /*net_specific=*/false)};
@@ -62,7 +62,7 @@ std::optional InitConfig(ArgsManager& args, SettingsAbortFn setting
fs::create_directories(net_path / "wallets");
}
- // Show an error or warning if there is a bitcoin.conf file in the
+ // Show an error or warning if there is a navcoin.conf file in the
// datadir that is being ignored.
const fs::path base_config_path = base_path / BITCOIN_CONF_FILENAME;
if (fs::exists(base_config_path) && !fs::equivalent(orig_config_path, base_config_path)) {
diff --git a/src/interfaces/node.h b/src/interfaces/node.h
index f4b01d5e4a320..253cfce337fe1 100644
--- a/src/interfaces/node.h
+++ b/src/interfaces/node.h
@@ -105,7 +105,7 @@ class Node
//! would be ignored because it is also specified in the command line.
virtual bool isSettingIgnored(const std::string& name) = 0;
- //! Return setting value from /settings.json or bitcoin.conf.
+ //! Return setting value from /settings.json or navcoin.conf.
virtual common::SettingsValue getPersistentSetting(const std::string& name) = 0;
//! Update a setting in /settings.json.
diff --git a/src/test/getarg_tests.cpp b/src/test/getarg_tests.cpp
index c73b675388da3..b95dc311f2db9 100644
--- a/src/test/getarg_tests.cpp
+++ b/src/test/getarg_tests.cpp
@@ -363,7 +363,7 @@ BOOST_AUTO_TEST_CASE(patharg)
// Check negated and default argument handling. Specifying an empty argument
// is the same as not specifying the argument. This is convenient for
// scripting so later command line arguments can override earlier command
- // line arguments or bitcoin.conf values. Currently the -dir= case cannot be
+ // line arguments or navcoin.conf values. Currently the -dir= case cannot be
// distinguished from -dir case with no assignment, but #16545 would add the
// ability to distinguish these in the future (and treat the no-assign case
// like an imperative command or an error).
diff --git a/contrib/devtools/gen-bitcoin-conf.sh b/contrib/devtools/gen-navcoin-conf.sh
similarity index 89%
rename from contrib/devtools/gen-bitcoin-conf.sh
rename to contrib/devtools/gen-navcoin-conf.sh
index ed5196edbf181..1a2a447124fa4 100755
--- a/contrib/devtools/gen-bitcoin-conf.sh
+++ b/contrib/devtools/gen-navcoin-conf.sh
@@ -9,7 +9,7 @@ BUILDDIR=${BUILDDIR:-$TOPDIR}
BINDIR=${BINDIR:-$BUILDDIR/src}
BITCOIND=${BITCOIND:-$BINDIR/navcoind}
SHARE_EXAMPLES_DIR=${SHARE_EXAMPLES_DIR:-$TOPDIR/share/examples}
-EXAMPLE_CONF_FILE=${EXAMPLE_CONF_FILE:-$SHARE_EXAMPLES_DIR/bitcoin.conf}
+EXAMPLE_CONF_FILE=${EXAMPLE_CONF_FILE:-$SHARE_EXAMPLES_DIR/navcoin.conf}
[ ! -x "$BITCOIND" ] && echo "$BITCOIND not found or not executable." && exit 1
@@ -22,10 +22,10 @@ fi
if [ -n "$DIRTY" ]
then
echo -e "WARNING: $BITCOIND was built from a dirty tree.\n"
- echo -e "To safely generate a bitcoin.conf file, please commit your changes to $BITCOIND, rebuild, then run this script again.\n"
+ echo -e "To safely generate a navcoin.conf file, please commit your changes to $BITCOIND, rebuild, then run this script again.\n"
fi
-echo 'Generating example bitcoin.conf file in share/examples/'
+echo 'Generating example navcoin.conf file in share/examples/'
# create the directory, if it doesn't exist
mkdir -p "${SHARE_EXAMPLES_DIR}"
@@ -33,8 +33,8 @@ mkdir -p "${SHARE_EXAMPLES_DIR}"
# create the header text
cat > "${EXAMPLE_CONF_FILE}" << 'EOF'
##
## bitcoin.conf configuration file.
## Generated by contrib/devtools/gen-bitcoin-conf.sh.
##
## Lines beginning with # are comments.
## All possible configuration options are provided. To use, copy this file
@@ -33,8 +33,8 @@ mkdir -p "${SHARE_EXAMPLES_DIR}"
cat > "${EXAMPLE_CONF_FILE}" << 'EOF'
##
-## bitcoin.conf configuration file.
-## Generated by contrib/devtools/gen-bitcoin-conf.sh.
+## navcoin.conf configuration file.
+## Generated by contrib/devtools/gen-navcoin-conf.sh.
##
## Lines beginning with # are comments.
diff --git a/contrib/guix/libexec/build.sh b/contrib/guix/libexec/build.sh
index b301369ad92eb..f922306d34c20 100755
--- a/contrib/guix/libexec/build.sh
+++ b/contrib/guix/libexec/build.sh
@@ -354,9 +354,9 @@ mkdir -p "$DISTSRC"
;;
esac
# copy over the example bitcoin.conf file. if contrib/devtools/gen-bitcoin-conf.sh
# has not been run before buildling, this file will be a stub
- cp "${DISTSRC}/share/examples/bitcoin.conf" "${DISTNAME}/"
+ cp "${DISTSRC}/share/examples/navcoin.conf" "${DISTNAME}/"
cp -r "${DISTSRC}/share/rpcauth" "${DISTNAME}/share/"
@@ -354,9 +354,9 @@ mkdir -p "$DISTSRC"
;;
esac
- # copy over the example bitcoin.conf file. if contrib/devtools/gen-bitcoin-conf.sh
+ # copy over the example navcoin.conf file. if contrib/devtools/gen-navcoin-conf.sh
# has not been run before buildling, this file will be a stub
diff --git a/test/functional/feature_config_args.py b/test/functional/feature_config_args.py
index a87305e4bc5bc..775713b7f78c5 100755
--- a/test/functional/feature_config_args.py
+++ b/test/functional/feature_config_args.py
@@ -31,8 +31,8 @@ def test_config_file_parser(self):
self.log.info('Test config file parser')
self.stop_node(0)
- # Check that startup fails if conf= is set in bitcoin.conf or in an included conf file
- bad_conf_file_path = self.nodes[0].datadir_path / "bitcoin_bad.conf"
+ # Check that startup fails if conf= is set in navcoin.conf or in an included conf file
+ bad_conf_file_path = self.nodes[0].datadir_path / "navcoin_bad.conf"
util.write_config(bad_conf_file_path, n=0, chain='', extra_config=f'conf=some.conf\n')
conf_in_config_file_err = 'Error: Error reading configuration file: conf cannot be set in the configuration file; use includeconf= if you want to include additional config files'
self.nodes[0].assert_start_raises_init_error(
@@ -75,7 +75,7 @@ def test_config_file_parser(self):
conf.write("wallet=foo\n")
self.nodes[0].assert_start_raises_init_error(expected_msg=f'Error: Config setting for -wallet only applied on {self.chain} network when in [{self.chain}] section.')
- main_conf_file_path = self.nodes[0].datadir_path / "bitcoin_main.conf"
+ main_conf_file_path = self.nodes[0].datadir_path / "navcoin_main.conf"
util.write_config(main_conf_file_path, n=0, chain='', extra_config=f'includeconf={inc_conf_file_path}\n')
with open(inc_conf_file_path, 'w', encoding='utf-8') as conf:
conf.write('acceptnonstdtxn=1\n')
@@ -126,11 +126,11 @@ def test_config_file_log(self):
env, default_datadir = util.get_temp_default_datadir(Path(self.options.tmpdir, "test_config_file_log"))
default_datadir.mkdir(parents=True)
# Write a bitcoin.conf file in the default data directory containing a
# datadir= line pointing at the node datadir.
node = self.nodes[0]
conf_text = node.bitcoinconf.read_text()
- conf_path = default_datadir / "bitcoin.conf"
+ conf_path = default_datadir / "navcoin.conf"
conf_path.write_text(f"datadir={node.datadir_path}\n{conf_text}")
# Drop the node -datadir= argument during this test, because if it is
@@ -320,20 +320,20 @@ def test_connect_with_seednode(self):
self.restart_node(0, extra_args=[connect_arg, '-seednode=fakeaddress2'])
def test_ignored_conf(self):
- self.log.info('Test error is triggered when the datadir in use contains a bitcoin.conf file that would be ignored '
+ self.log.info('Test error is triggered when the datadir in use contains a navcoin.conf file that would be ignored '
'because a conflicting -conf file argument is passed.')
node = self.nodes[0]
with tempfile.NamedTemporaryFile(dir=self.options.tmpdir, mode="wt", delete=False) as temp_conf:
temp_conf.write(f"datadir={node.datadir_path}\n")
node.assert_start_raises_init_error([f"-conf={temp_conf.name}"], re.escape(
- f'Error: Data directory "{node.datadir_path}" contains a "bitcoin.conf" file which is ignored, because a '
+ f'Error: Data directory "{node.datadir_path}" contains a "navcoin.conf" file which is ignored, because a '
f'different configuration file "{temp_conf.name}" from command line argument "-conf={temp_conf.name}" '
f'is being used instead.') + r"[\s\S]*", match=ErrorMatch.FULL_REGEX)
# Test that passing a redundant -conf command line argument pointing to
# the same bitcoin.conf that would be loaded anyway does not trigger an
# error.
- self.start_node(0, [f'-conf={node.datadir_path}/bitcoin.conf'])
+ self.start_node(0, [f'-conf={node.datadir_path}/navcoin.conf'])
self.stop_node(0)
def test_ignored_default_conf(self):
@@ -342,20 +342,20 @@ def test_ignored_default_conf(self):
if platform.system() == "Windows":
return
- self.log.info('Test error is triggered when bitcoin.conf in the default data directory sets another datadir '
- 'and it contains a different bitcoin.conf file that would be ignored')
+ self.log.info('Test error is triggered when navcoin.conf in the default data directory sets another datadir '
+ 'and it contains a different navcoin.conf file that would be ignored')
# Create a temporary directory that will be treated as the default data
# directory by bitcoind.
env, default_datadir = util.get_temp_default_datadir(Path(self.options.tmpdir, "home"))
default_datadir.mkdir(parents=True)
# Write a bitcoin.conf file in the default data directory containing a
# datadir= line pointing at the node datadir. This will trigger a
# startup error because the node datadir contains a different
# bitcoin.conf that would be ignored.
node = self.nodes[0]
- (default_datadir / "bitcoin.conf").write_text(f"datadir={node.datadir_path}\n")
+ (default_datadir / "navcoin.conf").write_text(f"datadir={node.datadir_path}\n")
# Drop the node -datadir= argument during this test, because if it is
# specified it would take precedence over the datadir setting in the
@@ -363,14 +363,14 @@ def test_ignored_default_conf(self):
node_args = node.args
node.args = [arg for arg in node.args if not arg.startswith("-datadir=")]
node.assert_start_raises_init_error([], re.escape(
- f'Error: Data directory "{node.datadir_path}" contains a "bitcoin.conf" file which is ignored, because a '
- f'different configuration file "{default_datadir}/bitcoin.conf" from data directory "{default_datadir}" '
+ f'Error: Data directory "{node.datadir_path}" contains a "navcoin.conf" file which is ignored, because a '
+ f'different configuration file "{default_datadir}/navcoin.conf" from data directory "{default_datadir}" '
f'is being used instead.') + r"[\s\S]*", env=env, match=ErrorMatch.FULL_REGEX)
node.args = node_args
def test_acceptstalefeeestimates_arg_support(self):
self.log.info("Test -acceptstalefeeestimates option support")
- conf_file = self.nodes[0].datadir_path / "bitcoin.conf"
+ conf_file = self.nodes[0].datadir_path / "navcoin.conf"
for chain, chain_name in {("main", ""), ("test", "testnet3"), ("signet", "signet")}:
util.write_config(conf_file, n=0, chain=chain_name, extra_config='acceptstalefeeestimates=1\n')
self.nodes[0].assert_start_raises_init_error(expected_msg=f'Error: acceptstalefeeestimates is not supported on {chain} chain.')
@@ -126,11 +126,11 @@ def test_config_file_log(self):
env, default_datadir = util.get_temp_default_datadir(Path(self.options.tmpdir, "test_config_file_log"))
default_datadir.mkdir(parents=True)
- # Write a bitcoin.conf file in the default data directory containing a
+ # Write a navcoin.conf file in the default data directory containing a
# datadir= line pointing at the node datadir.
node = self.nodes[0]
@@ -320,20 +320,20 @@ def test_connect_with_seednode(self):
f'is being used instead.') + r"[\s\S]*", match=ErrorMatch.FULL_REGEX)
# Test that passing a redundant -conf command line argument pointing to
- # the same bitcoin.conf that would be loaded anyway does not trigger an
+ # the same navcoin.conf that would be loaded anyway does not trigger an
# error.
@@ -342,20 +342,20 @@ def test_ignored_default_conf(self):
env, default_datadir = util.get_temp_default_datadir(Path(self.options.tmpdir, "home"))
default_datadir.mkdir(parents=True)
- # Write a bitcoin.conf file in the default data directory containing a
+ # Write a navcoin.conf file in the default data directory containing a
# datadir= line pointing at the node datadir. This will trigger a
# startup error because the node datadir contains a different
@@ -342,20 +342,20 @@ def test_ignored_default_conf(self):
# datadir= line pointing at the node datadir. This will trigger a
# startup error because the node datadir contains a different
- # bitcoin.conf that would be ignored.
+ # navcoin.conf that would be ignored.
node = self.nodes[0]